@@ -31,8 +31,11 @@ RE_HTTP_IGNORE_METHOD = RE_IGNORE_PATH  # type: re.Pattern
 options = None  # here to include 'options' in globals
 options = globals().copy()  # THIS MUST PRECEDE DIRECTLY BEFORE LIST OF CONFIG OPTIONS!
 
-yamlPath = os.path.join("/usr/local", "skywalking-config.yml")
+yamlPath = os.path.join("/etc", "skywalking-config.yml")
 data = None
+service_instance = None
+trace_ignore_path = None
+
 if os.path.exists(yamlPath):
     f = open(yamlPath, 'r', encoding='utf-8')
     cfg = f.read()
